<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr" sourcelanguage="en">
<context>
    <name>AgendaPlug</name>
    <message>
        <location filename="../AgendaPlug.cpp" line="26"/>
        <source>Jump to today</source>
        <translation>Aller à aujourd&apos;hui</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="27"/>
        <source>Jump to</source>
        <translation>Aller à</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="28"/>
        <location filename="../AgendaPlug.cpp" line="122"/>
        <source>New event</source>
        <translation>Nouvel évènement</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.h" line="17"/>
        <source>Agenda</source>
        <translation>Agenda</translation>
    </message>
</context>
<context>
    <name>AlarmPickDialog</name>
    <message>
        <location filename="../AlarmPickDialog.ui" line="6"/>
        <source>Alarm</source>
        <translation>Alarme</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="27"/>
        <source>Time in advance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="37"/>
        <source>Hours</source>
        <translation>Heures</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="57"/>
        <source>Minutes</source>
        <translation>Minutes</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="77"/>
        <source>Seconds</source>
        <translation>Secondes</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="17"/>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.cpp" line="13"/>
        <source>Done</source>
        <translation>Effectué</translation>
    </message>
</context>
<context>
    <name>AlarmPickSelector</name>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="26"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="37"/>
        <source>Exact</source>
        <translation>Exactement</translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="39"/>
        <source>%n hour(s) before</source>
        <translation>
            <numerusform>%n heure avant</numerusform>
            <numerusform>%n heures avant</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="40"/>
        <source>%n minute(s) before</source>
        <translation>
            <numerusform>%n minute avant</numerusform>
            <numerusform>%n minutes avant</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="41"/>
        <source>%n second(s) before</source>
        <translation>
            <numerusform>%n seconde avant</numerusform>
            <numerusform>%n secondes avant</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="43"/>
        <source>%1:%2:%3 before</source>
        <translation>%1:%2:%3 avant</translation>
    </message>
</context>
<context>
    <name>ByDayWidget</name>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="22"/>
        <source>From beginning</source>
        <translation>Depuis le début</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="23"/>
        <source>From end</source>
        <translation>Depuis la fin</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="33"/>
        <source>By day of month</source>
        <translation>Par jours du mois</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="35"/>
        <source>By week of year</source>
        <translation>Par semaine de l&apos;année</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="37"/>
        <source>By day of year</source>
        <translation>Par jour de l&apos;année</translation>
    </message>
</context>
<context>
    <name>ByMonthWidget</name>
    <message>
        <location filename="../recurrence/ByMonthWidget.cpp" line="21"/>
        <source>By month</source>
        <translation>Par mois</translation>
    </message>
</context>
<context>
    <name>ByWeekdayWidget</name>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="18"/>
        <source>By day of week</source>
        <translation>Par jours de la semaine</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="36"/>
        <source>From beginning</source>
        <translation>Depuis le début</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="37"/>
        <source>From end</source>
        <translation>Depuis la fin</translation>
    </message>
</context>
<context>
    <name>CalendarEditDialog</name>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="6"/>
        <source>Edit calendar</source>
        <translation>Modifier le calendrier</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="56"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="66"/>
        <source>Visible</source>
        <translation>Visible</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="26"/>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="27"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="28"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="131"/>
        <source>Save file</source>
        <translation>Sauvegarder le fichier</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="144"/>
        <source>Delete this calendar and its events, tasks and notes?</source>
        <translation>Supprimer ce calendrier ainsi que ses évènements, tâches et notes?</translation>
    </message>
</context>
<context>
    <name>CalendarPickDialog</name>
    <message>
        <location filename="../CalendarPickDialog.ui" line="6"/>
        <source>Calendar</source>
        <translation>Calendrier</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigDialog</name>
    <message>
        <location filename="../settings/CalendarsConfigDialog.ui" line="6"/>
        <source>Edit calendars</source>
        <translation>Modifier les calendriers</translation>
    </message>
    <message>
        <location filename="../settings/CalendarsConfigDialog.cpp" line="25"/>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigSelector</name>
    <message numerus="yes">
        <location filename="../settings/CalendarsConfigSelector.cpp" line="16"/>
        <source>%n visible</source>
        <translation>
            <numerusform>%n visible</numerusform>
            <numerusform>%n visible</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ColorPickDialog</name>
    <message>
        <location filename="../ColorPickDialog.ui" line="6"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <location filename="../ColorPickDialog.cpp" line="12"/>
        <source>Done</source>
        <translation>Effectué</translation>
    </message>
</context>
<context>
    <name>ComponentEditDialog</name>
    <message>
        <location filename="../ComponentEditDialog.h" line="22"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../ComponentEditDialog.h" line="29"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>ComponentListDelegate</name>
    <message>
        <location filename="../ComponentListDelegate.h" line="80"/>
        <source>All
day</source>
        <translation>Toute la
journée</translation>
    </message>
</context>
<context>
    <name>ComponentListWidget</name>
    <message>
        <location filename="../ComponentListWidget.cpp" line="72"/>
        <source>Edit</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="73"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>ComponentWidget</name>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="181"/>
        <source>Edit</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="182"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>DatePickDialog</name>
    <message>
        <location filename="../DatePickDialog.cpp" line="27"/>
        <source>Done</source>
        <translation>Effectué</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.cpp" line="180"/>
        <source>Week %1 (%2 - %3)</source>
        <translation>Semaine %1 (%2 - %3)</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.ui" line="6"/>
        <source>Select date</source>
        <translation>Choisir la date</translation>
    </message>
</context>
<context>
    <name>DayNumberDialog</name>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="17"/>
        <source>Enter day number</source>
        <translation>Entrer la date</translation>
    </message>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="24"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
</context>
<context>
    <name>DayWindow</name>
    <message>
        <location filename="../DayWindow.ui" line="35"/>
        <source>Previous day</source>
        <translation>Jour précédent</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="40"/>
        <source>Next day</source>
        <translation>Jour suivant</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="45"/>
        <source>Jump to today</source>
        <translation>Aller à aujourd&apos;hui</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="50"/>
        <source>Jump to</source>
        <translation>Aller à</translation>
    </message>
    <message>
        <location filename="../DayWindow.cpp" line="36"/>
        <source>New event</source>
        <translation>Nouvel évènement</translation>
    </message>
</context>
<context>
    <name>DetailedCalendarDelegate</name>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="30"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n évènement</numerusform>
            <numerusform>%n évènements</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="31"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n tâche</numerusform>
            <numerusform>%n tâches</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="32"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n note</numerusform>
            <numerusform>%n notes</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>EventEditDialog</name>
    <message>
        <location filename="../EventEditDialog.ui" line="27"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="40"/>
        <source>Where</source>
        <translation>Lieu</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="55"/>
        <source>All day</source>
        <translation>Toute la journée</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="64"/>
        <source>From</source>
        <translation>Du</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="90"/>
        <source>To</source>
        <translation>Au</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="118"/>
        <source>Repeat</source>
        <translation>Répéter</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="128"/>
        <source>Calendar</source>
        <translation>Calendrier</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="135"/>
        <source>Alarm</source>
        <translation>Alarme</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="69"/>
        <source>Edit event</source>
        <translation>Modifier l&apos;évènement</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="87"/>
        <source>New event</source>
        <translation>Nouvel évènement</translation>
    </message>
</context>
<context>
    <name>EventWindow</name>
    <message>
        <location filename="../EventWindow.ui" line="6"/>
        <source>Event</source>
        <translation>Evènement</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="62"/>
        <source>To</source>
        <translation>Au</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="86"/>
        <source>Repeat</source>
        <translation>Répéter</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="110"/>
        <source>Alarm</source>
        <translation>Alarme</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="177"/>
        <source>Previous event</source>
        <translation>Evènement précédent</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="182"/>
        <source>Next event</source>
        <translation>Evènement suivant</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="187"/>
        <source>Edit event</source>
        <translation>Modifier l&apos;évènement</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="192"/>
        <source>Delete event</source>
        <translation>Supprimer l&apos;évènement</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="133"/>
        <source>From</source>
        <translation>Du</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="133"/>
        <source>On</source>
        <translation>Le</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="203"/>
        <location filename="../EventWindow.cpp" line="224"/>
        <source>No more events</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExpandingTextEdit</name>
    <message>
        <location filename="../ExpandingTextEdit.cpp" line="101"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
</context>
<context>
    <name>JournalEditDialog</name>
    <message>
        <location filename="../JournalEditDialog.ui" line="17"/>
        <source>Calendar</source>
        <translation>Calendrier</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="24"/>
        <source>Edit note</source>
        <translation>Modifier la note</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="32"/>
        <source>New note</source>
        <translation>Nouvelle note</translation>
    </message>
</context>
<context>
    <name>JournalsPlug</name>
    <message>
        <location filename="../JournalsPlug.cpp" line="27"/>
        <source>New note</source>
        <translation>Nouvelle note</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="46"/>
        <source>Notes</source>
        <translation>Notes</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="120"/>
        <source>Edit</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="121"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="56"/>
        <source>Month</source>
        <translation>Mois</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="57"/>
        <source>Week</source>
        <translation>Semaine</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="58"/>
        <source>Agenda</source>
        <translation>Agenda</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="59"/>
        <source>Tasks</source>
        <translation>Tâches</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="60"/>
        <source>Notes</source>
        <translation>Notes</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="61"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
</context>
<context>
    <name>MonthPlug</name>
    <message>
        <location filename="../month/MonthPlug.cpp" line="63"/>
        <source>Previous month</source>
        <translation>Mois précédent</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="64"/>
        <source>Next month</source>
        <translation>Mois suivant</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="65"/>
        <source>Jump to today</source>
        <translation>Aller à aujourd&apos;hui</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="66"/>
        <source>Jump to</source>
        <translation>Aller à</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="67"/>
        <source>New event</source>
        <translation>Nouvel évènement</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ChangeManager.cpp" line="47"/>
        <source>Unable to edit birthdays</source>
        <translation>Impossible de modifier les anniversaires</translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="57"/>
        <source>Delete component?</source>
        <translation>Supprimer l&apos;élément?</translation>
    </message>
</context>
<context>
    <name>RecurrencePickDialog</name>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="6"/>
        <source>Recurrence</source>
        <translation>Récurrence</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="28"/>
        <source>Repeat</source>
        <translation>Répéter</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="50"/>
        <source>Frequency</source>
        <translation>Fréquence</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="61"/>
        <source>Daily</source>
        <translation>Quotidien</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="66"/>
        <source>Weekly</source>
        <translation>Hebdomadaire</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="71"/>
        <source>Monthly</source>
        <translation>Mensuel</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="76"/>
        <source>Yearly</source>
        <translation>Annuel</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="84"/>
        <source>Interval</source>
        <translation>Intervalle</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="108"/>
        <source>Forever</source>
        <translation>Pour toujours</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="113"/>
        <source>Until</source>
        <translation>Jusqu&apos;au</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="118"/>
        <source>Count</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.cpp" line="32"/>
        <source>Done</source>
        <translation>Effectué</translation>
    </message>
</context>
<context>
    <name>RecurrencePickSelector</name>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="28"/>
        <source>Never</source>
        <translation>Jamais</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="30"/>
        <source>External</source>
        <translation>Externe</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="32"/>
        <source>Every day</source>
        <translation>Tous les jours</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="34"/>
        <source>Every workday</source>
        <translation>Tous les jours travaillés</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="36"/>
        <source>Every week</source>
        <translation>Toutes les semaines</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="38"/>
        <source>Every month</source>
        <translation>Tous les mois</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="40"/>
        <source>Every year</source>
        <translation>Tous les ans</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="42"/>
        <source>Complex</source>
        <translation>Complexe</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="6"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="32"/>
        <source>Edit calendars</source>
        <translation>Modifier les calendriers</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="42"/>
        <source>Delete events</source>
        <translation>Supprimer les évènements</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="52"/>
        <source>Delete tasks</source>
        <translation>Supprimer les tâches</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="14"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="43"/>
        <source>Never</source>
        <translation>Jamais</translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="45"/>
        <location filename="../settings/SettingsDialog.cpp" line="47"/>
        <source>Older than %n week(s)</source>
        <translation>
            <numerusform>Plus vieux que %n semaine</numerusform>
            <numerusform>Plus vieux que %n semaines</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="49"/>
        <source>Older than %n month(s)</source>
        <translation>
            <numerusform>Plus vieux que %n mois</numerusform>
            <numerusform>Plus vieux que %n mois</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="51"/>
        <source>Older than %n year(s)</source>
        <translation>
            <numerusform>Plus vieux que %n an</numerusform>
            <numerusform>Plus vieux que %n ans</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TodoEditDialog</name>
    <message>
        <location filename="../TodoEditDialog.ui" line="28"/>
        <source>Done</source>
        <translation>Effectué</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="35"/>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="42"/>
        <source>Calendar</source>
        <translation>Calendrier</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="49"/>
        <location filename="../TodoEditDialog.ui" line="61"/>
        <source>Alarm</source>
        <translation>Alarme</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="44"/>
        <source>Edit task</source>
        <translation>Modifier la tâche</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="61"/>
        <source>New task</source>
        <translation>Nouvelle tâche</translation>
    </message>
</context>
<context>
    <name>TodoWindow</name>
    <message>
        <location filename="../TodoWindow.ui" line="6"/>
        <source>Task</source>
        <translation>Tâche</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="41"/>
        <source>Done</source>
        <translation>Effectué</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="50"/>
        <source>Due</source>
        <translation>Pour le</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="80"/>
        <source>Alarm</source>
        <translation>Alarme</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="167"/>
        <source>Edit task</source>
        <translation>Modifier la tâche</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="172"/>
        <source>Delete task</source>
        <translation>Supprimer la tâche</translation>
    </message>
</context>
<context>
    <name>TodosPlug</name>
    <message>
        <location filename="../TodosPlug.cpp" line="33"/>
        <source>New task</source>
        <translation>Nouvelle tâche</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="40"/>
        <source>Hide completed</source>
        <translation>Masquer les terminées</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="41"/>
        <source>Delete completed</source>
        <translation>Supprimer les terminées</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="78"/>
        <source>Tasks</source>
        <translation>Tâches</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="198"/>
        <source>Edit</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="199"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="224"/>
        <source>Delete completed tasks from all calendars?</source>
        <translation>Supprimer les tâches terminées de tous les calendrier?</translation>
    </message>
</context>
<context>
    <name>WeekButton</name>
    <message>
        <location filename="../month/WeekButton.cpp" line="31"/>
        <source>w%1</source>
        <translation>w%1</translation>
    </message>
</context>
<context>
    <name>WeekPlug</name>
    <message>
        <location filename="../week/WeekPlug.cpp" line="42"/>
        <source>Previous week</source>
        <translation>Semaine précédente</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="43"/>
        <source>Next week</source>
        <translation>Semaine suivante</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="44"/>
        <source>Jump to today</source>
        <translation>Aller à aujourd&apos;hui</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="45"/>
        <source>Jump to</source>
        <translation>Aller à</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="46"/>
        <source>New event</source>
        <translation>Nouvel évènement</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="69"/>
        <source>Week %1 (%2)</source>
        <translation>Semaine %1 (%2)</translation>
    </message>
</context>
<context>
    <name>WeekWidget</name>
    <message>
        <location filename="../week/WeekWidget.cpp" line="357"/>
        <source>All day</source>
        <translation>Toute la journée</translation>
    </message>
</context>
</TS>
